@@ -15,11 +15,10 @@ is common for both shells and editors.
 import pyzo
 import os, sys, time
 import weakref
-from pyzolib import ssdf
 from pyzo.core.pyzoLogging import print
 import pyzo.codeeditor.parsers.tokens as Tokens
 
-from pyzolib.qt import QtCore, QtGui
+from pyzo.util.qt import QtCore, QtGui, QtWidgets
 qt = QtGui
 
 
@@ -116,11 +115,12 @@ def parseLine_signature(tokens):
     - location of end bracket
     - amount of kommas till cursor (taking nested brackets into account)
     """
+    
     openBraces = [] #Positions at which braces are opened
     for token in tokens:
-        if not isinstance(token,Tokens.NonIdentifierToken):
+        if not isinstance(token, (Tokens.NonIdentifierToken, Tokens.OpenParenToken)):
             continue
-        for i,c in enumerate(str(token)):
+        for i, c in enumerate(str(token)):
             if c=='(':
                 openBraces.append(token.start + i)
             elif c==')':
@@ -136,10 +136,8 @@ def parseLine_signature(tokens):
             tokens[-1].end = i
         
         name, needle = parseLine_autocomplete(tokens)
-
         return name, needle, (i,0) #TODO: implement stats
-        
-        
+    
     return "","",(0,0)
 
 
@@ -609,7 +607,7 @@ class AutoCompObject:
     
     
 if __name__=="__main__":
-    app = QtGui.QApplication([])
+    app = QtWidgets.QApplication([])
     win = BaseTextCtrl(None)
 #     win.setStyle('.py')
     tmp = "foo(bar)\nfor bar in range(5):\n  print bar\n"
