@@ -16,9 +16,9 @@ import signal
 import threading
 import ctypes
 
-from pyzolib import ssdf
 import yoton
 import pyzo # local Pyzo (can be on a different box than where the user is)
+from pyzo.util import zon as ssdf  # zon is ssdf-light
 
 
 # To allow interpreters relative to (frozen) Pyzo app
@@ -54,7 +54,7 @@ class KernelInfo(ssdf.Struct):
     
     """
     def __init__(self, info=None):
-        
+        super().__init__()
         # ----- Fixed parameters that define a shell -----
         
         # scriptFile is used to define the mode. If given, we run in 
@@ -111,8 +111,6 @@ class KernelInfo(ssdf.Struct):
             # Get struct
             if isinstance(info, dict):
                 s = info
-            elif ssdf.isstruct(info):
-                s = info
             elif isinstance(info, str):
                 s = ssdf.loads(info)
             else:
