@@ -11,21 +11,22 @@ import sys
 import time
 import subprocess
 import fnmatch
-from pyzolib.path import Path
+import os.path as op
 
-from . import QtCore, QtGui
 import pyzo
 from pyzo import translate
+from . import QtCore, QtGui, QtWidgets
 
 from . import tasks
-from .utils import hasHiddenAttribute, getMounts
+from .utils import hasHiddenAttribute, getMounts, cleanpath, isdir, ext
+
 
 # How to name the list of drives/mounts (i.e. 'my computer')
 MOUNTS = 'drives'
 
 
 # Create icon provider
-iconprovider = QtGui.QFileIconProvider()
+iconprovider = QtWidgets.QFileIconProvider()
 
 
 def addIconOverlays(icon, *overlays, offset=(8,0), overlay_offset=(0,0)):
@@ -82,7 +83,7 @@ def createMounts(browser, tree):
     mountPoints = getMounts()
     mountPoints.sort(key=lambda x: x.lower())
     for entry in mountPoints:
-        entry = Path(entry)
+        entry = cleanpath(entry)
         item = DriveItem(tree, fsProxy.dir(entry))
 
 
@@ -106,23 +107,23 @@ def createItemsFun(browser, parent):
     try:
         dirs = []
         for entry in dirProxy.dirs():
-            entry = Path(entry)
-            if entry.basename.startswith('.'):
+            entry = cleanpath(entry)
+            if op.basename(entry).startswith('.'):
                 continue # Skip hidden files
             if hasHiddenAttribute(entry):
                 continue # Skip hidden files on Windows
-            if entry.basename == '__pycache__':
+            if op.basename(entry) == '__pycache__':
                 continue
             dirs.append(entry)
         
         files = []
         for entry in dirProxy.files():
-            entry = Path(entry)
-            if entry.basename.startswith('.'):
+            entry = cleanpath(entry)
+            if op.basename(entry).startswith('.'):
                 continue # Skip hidden files
             if hasHiddenAttribute(entry):
                 continue # Skip hidden files on Windows
-            if not _filterFileByName(entry.basename, nameFilter):
+            if not _filterFileByName(op.basename(entry), nameFilter):
                 continue
             files.append(entry)
     
@@ -136,19 +137,19 @@ def createItemsFun(browser, parent):
     # Sort files 
     # (first by name, then by type, so finally they are by type, then name)
     files.sort(key=lambda x: x.lower())
-    files.sort(key=lambda x: x.ext.lower())
+    files.sort(key=lambda x: ext(x).lower())
         
     
     if not searchFilter:
         
         # Create dirs 
         for path in dirs:
-            starred = path.normcase() in starredDirs
+            starred = op.normcase(path) in starredDirs
             item = DirItem(parent, fsProxy.dir(path), starred)
             # Set hidden, we can safely expand programmatically when hidden
             item.setHidden(True)
             # Set expanded and visibility
-            if path.normcase() in expandedDirs:
+            if op.normcase(path) in expandedDirs:
                 item.setExpanded(True)
             item.setHidden(False)
         
@@ -185,13 +186,13 @@ def createItemsFun(browser, parent):
 
 
 
-class BrowserItem(QtGui.QTreeWidgetItem):
+class BrowserItem(QtWidgets.QTreeWidgetItem):
     """ Abstract item in the tree widget.
     """
     
     def __init__(self, parent, pathProxy, *args):
         self._proxy = pathProxy
-        QtGui.QTreeWidgetItem.__init__(self, parent, [], *args)
+        QtWidgets.QTreeWidgetItem.__init__(self, parent, [], *args)
         # Set pathname to show, and icon
         strippedParentPath = parent.path().rstrip('/\\')
         if self.path().startswith(strippedParentPath):
@@ -211,7 +212,7 @@ class BrowserItem(QtGui.QTreeWidgetItem):
     
     def _createDummyItem(self, txt):
         ErrorItem(self, txt)
-        #QtGui.QTreeWidgetItem(self, [txt])
+        #QtWidgets.QTreeWidgetItem(self, [txt])
     
     def onDestroyed(self):
         self._proxy.cancel()
@@ -288,7 +289,7 @@ class DirItem(BrowserItem):
     def onExpanded(self):
         # Update list of expanded dirs
         expandedDirs = self.treeWidget().parent().expandedDirs
-        p = self.path().normcase()  # Normalize case!
+        p = op.normcase(self.path())  # Normalize case!
         if p not in expandedDirs:
             expandedDirs.append(p) 
         # Keep track of changes in our contents
@@ -298,7 +299,7 @@ class DirItem(BrowserItem):
     def onCollapsed(self):
         # Update list of expanded dirs
         expandedDirs = self.treeWidget().parent().expandedDirs
-        p = self.path().normcase()   # Normalize case!
+        p = op.normcase(self.path())   # Normalize case!
         while p in expandedDirs:
             expandedDirs.remove(p)
         # Stop tracking changes in our contents
@@ -335,11 +336,11 @@ class FileItem(BrowserItem):
     
     def setFileIcon(self):
         # Create dummy file in pyzo user dir
-        dummy_filename = Path(pyzo.appDataDir) / 'dummyFiles' / 'dummy' + self.path().ext
+        dummy_filename = op.join(cleanpath(pyzo.appDataDir), 'dummyFiles', 'dummy' + ext(self.path()))
         # Create file?
-        if not dummy_filename.isfile:
-            if not dummy_filename.dirname.isdir:
-                os.makedirs(dummy_filename.dirname)
+        if not op.isfile(dummy_filename):
+            if not isdir(op.dirname(dummy_filename)):
+                os.makedirs(op.dirname(dummy_filename))
             f = open(dummy_filename, 'wb')
             f.close()
         # Use that file
@@ -359,7 +360,7 @@ class FileItem(BrowserItem):
         # todo: someday we should be able to simply pass the proxy object to the editors
         # so that we can open files on any file system
         path = self.path()
-        if path.ext not in ['.pyc','.pyo','.png','.jpg','.ico']:
+        if ext(path) not in ['.pyc','.pyo','.png','.jpg','.ico']:
             # Load and get editor
             fileItem = pyzo.editors.loadFile(path)
             editor = fileItem._editor
@@ -406,7 +407,7 @@ class FileItem(BrowserItem):
 #                 tree = self.treeWidget()
 #                 pos = tree.mapFromGlobal(QtGui.QCursor.pos())
 #                 if tree.itemAt(pos) is self:
-#                     QtGui.QToolTip.showText(QtGui.QCursor.pos(), result)
+#                     QtWidgets.QToolTip.showText(QtGui.QCursor.pos(), result)
         elif isinstance(task, tasks.PeekTask):
             result = task.result()
             #self.clear()  # Cleared when docstring task result is received
@@ -420,11 +421,11 @@ class FileItem(BrowserItem):
 
 
 
-class SubFileItem(QtGui.QTreeWidgetItem):
+class SubFileItem(QtWidgets.QTreeWidgetItem):
     """ Tree widget item for search items.
     """
     def __init__(self, parent, linenr, text, showlinenr=False):
-        QtGui.QTreeWidgetItem.__init__(self, parent)
+        QtWidgets.QTreeWidgetItem.__init__(self, parent)
         self._linenr = linenr
         if showlinenr:
             self.setText(0, 'Line %i: %s' % (linenr, text))
@@ -436,7 +437,7 @@ class SubFileItem(QtGui.QTreeWidgetItem):
     
     def onActivated(self):
         path = self.path()
-        if path.ext not in ['.pyc','.pyo','.png','.jpg','.ico']:
+        if ext(path) not in ['.pyc','.pyo','.png','.jpg','.ico']:
             # Load and get editor
             fileItem = pyzo.editors.loadFile(path)
             editor = fileItem._editor
@@ -447,12 +448,12 @@ class SubFileItem(QtGui.QTreeWidgetItem):
 
 
 
-class DocstringItem(QtGui.QTreeWidgetItem):
+class DocstringItem(QtWidgets.QTreeWidgetItem):
     """ Tree widget item for docstring placeholder items.
     """
     
     def __init__(self, parent, docstring):
-        QtGui.QTreeWidgetItem.__init__(self, parent)
+        QtWidgets.QTreeWidgetItem.__init__(self, parent)
         self._docstring = docstring
         # Get one-line version of docstring
         shortText = self._docstring.split('\n',1)[0].strip()
@@ -470,15 +471,15 @@ class DocstringItem(QtGui.QTreeWidgetItem):
         tree = self.treeWidget()
         pos = tree.mapFromGlobal(QtGui.QCursor.pos())
         if tree.itemAt(pos) is self:
-            QtGui.QToolTip.showText(QtGui.QCursor.pos(), self._docstring)
+            QtWidgets.QToolTip.showText(QtGui.QCursor.pos(), self._docstring)
 
 
 
-class ErrorItem(QtGui.QTreeWidgetItem):
+class ErrorItem(QtWidgets.QTreeWidgetItem):
     """ Tree widget item for errors and information.
     """
     def __init__(self, parent, info):
-        QtGui.QTreeWidgetItem.__init__(self, parent)
+        QtWidgets.QTreeWidgetItem.__init__(self, parent)
         self.setText(0, info)
         self.setFlags(QtCore.Qt.NoItemFlags)
         font = self.font(0)
@@ -574,16 +575,16 @@ class TemporaryFileItem:
 
 
 
-class Tree(QtGui.QTreeWidget):
+class Tree(QtWidgets.QTreeWidget):
     """ Representation of the tree view.
     Instances of this class are responsible for keeping the contents
     up-to-date. The Item classes above are dumb objects.
     """
     
-    dirChanged = QtCore.Signal(Path) # Emitted when user goes into a subdir
+    dirChanged = QtCore.Signal(str) # Emitted when user goes into a subdir
     
     def __init__(self, parent):
-        QtGui.QTreeWidget.__init__(self, parent)
+        QtWidgets.QTreeWidget.__init__(self, parent)
         
         # Initialize
         self.setMinimumWidth(150)
@@ -654,10 +655,10 @@ class Tree(QtGui.QTreeWidget):
     def setPathUp(self):
         """ Go one directory up.
         """
-        newPath = self.path().dirname
+        newPath = op.dirname(self.path())
         
-        if newPath == self.path():
-            self.setPath(Path(MOUNTS))
+        if op.normcase(newPath) == op.normcase(self.path()):
+            self.setPath(cleanpath(MOUNTS))
         else:
             self.setPath(newPath)
     
@@ -677,7 +678,7 @@ class Tree(QtGui.QTreeWidget):
                 item.clear()
             if hasattr(item, 'onDestroyed'):
                 item.onDestroyed()
-        QtGui.QTreeWidget.clear(self)
+        QtWidgets.QTreeWidget.clear(self)
     
     
     def mouseDoubleClickEvent(self, event):
@@ -706,7 +707,7 @@ class Tree(QtGui.QTreeWidget):
         parent.clear()
         # Create sub items
         count = createItemsFun(self.parent(), parent)
-        if not count and isinstance(parent, QtGui.QTreeWidgetItem):
+        if not count and isinstance(parent, QtWidgets.QTreeWidgetItem):
             ErrorItem(parent, 'Empty directory')
         # Restore state
         self._restoreSelectionState()
@@ -754,8 +755,8 @@ class Tree(QtGui.QTreeWidget):
             self.setCurrentItem(self.topLevelItem(0))       
         # Restore selection
         if self._selectedPath:
-            items = self.findItems(self._selectedPath.basename, QtCore.Qt.MatchExactly, 0)
-            items = [item for item in items if item.path() == self._selectedPath]
+            items = self.findItems(op.basename(self._selectedPath), QtCore.Qt.MatchExactly, 0)
+            items = [item for item in items if op.normcase(item.path()) == op.normcase(self._selectedPath)]
             if items:
                 self.setCurrentItem(items[0])
         # Restore scrolling
@@ -847,20 +848,24 @@ class PopupMenu(pyzo.core.menu.Menu):
         self.parent().setPath(self.parent().path())
     
     def _openOutsidePyzo(self):
+        path = self._item.path()
         if sys.platform.startswith('darwin'):
-            subprocess.call(('open', self._item.path()))
+            subprocess.call(('open', path))
         elif sys.platform.startswith('win'):
-            subprocess.call(('start', self._item.path()), shell=True)
+            if ' ' in path:  # http://stackoverflow.com/a/72796/2271927
+                subprocess.call(('start', '', path), shell=True)
+            else:
+                subprocess.call(('start', path), shell=True)
         elif sys.platform.startswith('linux'):
             # xdg-open is available on all Freedesktop.org compliant distros
             # http://superuser.com/questions/38984/linux-equivalent-command-for-open-command-on-mac-windows
-            subprocess.call(('xdg-open', self._item.path()))
+            subprocess.call(('xdg-open', path))
     
     def _showInFinder(self):
         subprocess.call(('open', '-R', self._item.path()))
     
     def _copyPath(self):
-        QtGui.qApp.clipboard().setText(self._item.path())
+        QtWidgets.qApp.clipboard().setText(self._item.path())
     
     def _runAsScript(self):
         filename = self._item.path()
@@ -869,7 +874,7 @@ class PopupMenu(pyzo.core.menu.Menu):
             shell.restart(filename)
         else:
             msg = "No shell to run code in. "
-            m = QtGui.QMessageBox(self)
+            m = QtWidgets.QMessageBox(self)
             m.setWindowTitle(translate("menu dialog", "Could not run"))
             m.setText("Could not run " + filename + ":\n\n" + msg)
             m.setIcon(m.Warning)
@@ -882,7 +887,7 @@ class PopupMenu(pyzo.core.menu.Menu):
             shell.restart(filename)
         else:
             msg = "No shell to run notebook in. "
-            m = QtGui.QMessageBox(self)
+            m = QtWidgets.QMessageBox(self)
             m.setWindowTitle(translate("menu dialog", "Could not run notebook"))
             m.setText("Could not run " + filename + ":\n\n" + msg)
             m.setIcon(m.Warning)
@@ -917,9 +922,9 @@ class PopupMenu(pyzo.core.menu.Menu):
             label = translate("filebrowser", "Give the name for the new directory")
         
         # Ask for new filename
-        s = QtGui.QInputDialog.getText(self.parent(), title,
+        s = QtWidgets.QInputDialog.getText(self.parent(), title,
                     label + ':\n%s' % self._item.path(),
-                    QtGui.QLineEdit.Normal,
+                    QtWidgets.QLineEdit.Normal,
                     'new name'
                 )
         if isinstance(s, tuple):
@@ -927,7 +932,7 @@ class PopupMenu(pyzo.core.menu.Menu):
         
         # Push rename task
         if s:
-            newpath = os.path.join(self._item.path(), s)
+            newpath = op.join(self._item.path(), s)
             task = tasks.CreateTask(newpath=newpath, file=file)
             self._item._proxy.pushTask(task)
     
@@ -935,7 +940,7 @@ class PopupMenu(pyzo.core.menu.Menu):
     def _duplicateOrRename(self, rename):
         
         # Get dirname and filename
-        dirname, filename = os.path.split(self._item.path())
+        dirname, filename = op.split(self._item.path())
         
         # Get title and label
         if rename:
@@ -947,9 +952,9 @@ class PopupMenu(pyzo.core.menu.Menu):
             filename = 'Copy of ' + filename
         
         # Ask for new filename
-        s = QtGui.QInputDialog.getText(self.parent(), title,
+        s = QtWidgets.QInputDialog.getText(self.parent(), title,
                     label + ':\n%s' % self._item.path(),
-                    QtGui.QLineEdit.Normal,
+                    QtWidgets.QLineEdit.Normal,
                     filename
                 )
         if isinstance(s, tuple):
@@ -957,19 +962,19 @@ class PopupMenu(pyzo.core.menu.Menu):
         
         # Push rename task
         if s:
-            newpath = os.path.join(dirname, s)
+            newpath = op.join(dirname, s)
             task = tasks.RenameTask(newpath=newpath, removeold=rename)
             self._item._proxy.pushTask(task)
     
     
     def onDelete(self):
         # Ask for new filename
-        b = QtGui.QMessageBox.question(self.parent(), 
+        b = QtWidgets.QMessageBox.question(self.parent(), 
                     translate("filebrowser", "Delete"), 
                     translate("filebrowser", "Are you sure that you want to delete") + 
                     ':\n%s' % self._item.path(),
-                    QtGui.QMessageBox.Yes | QtGui.QMessageBox.Cancel,
+                    QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.Cancel,
                 )       
         # Push delete task
-        if b is QtGui.QMessageBox.Yes:            
+        if b is QtWidgets.QMessageBox.Yes:            
             self._item._proxy.pushTask(tasks.RemoveTask())
